
:mod:`pyrcel.distributions`.Lognorm
==========================================

.. currentmodule:: pyrcel.distributions

.. autoclass:: Lognorm
   :members:
   :undoc-members:

   
   .. automethod:: __init__
   
